%define debug_package %{nil}

Summary:	AVML - Acquire Volatile Memory for Linux

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		cert.org
Name:		avml
%if 0%{?centos} == 8 || 0%{?centos} == 7
Version:	0.3.0
%else
Version:	0.11.3
%endif
Release:	1%{?dist}
URL:		https://github.com/microsoft/avml

License:	MIT

Group:		Applications/Forensics Tools
Source:		%{name}-%{version}.tar.gz

BuildRoot:	%{_tmppath}/rpm-root-%{name}-v%{version}
#BuildRequires:	musl-devel musl-gcc cargo curl perl(FindBin) perl-File-Compare
BuildRequires:	musl-devel musl-gcc curl perl(FindBin) perl-File-Compare

%description
AVML is an X86_64 userland volatile memory acquisition tool written in Rust, intended to be deployed as a static binary.
AVML can be used to acquire memory without knowing the target OS distribution or kernel a priori. No on-target compilation or fingerprinting is needed.

Features:
 * Save recorded images to external locations via Azure Blob Store or HTTP PUT
 * Automatic Retry (in case of network connection issues) with exponential backoff for uploading to Azure Blob Store
 * Optional page level compression using Snappy.
 * Uses LiME output format (when not using compression).

Memory Sources
 * /dev/crash
 * /proc/kcore
 * /dev/mem

%prep
%setup 

%build
CFLAGS=`echo $CFLAGS | sed -e 's/-Wp,-D_FORTIFY_SOURCE=2//' -e 's/-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3//'`
curl https://sh.rustup.rs -sSf | sh -s -- -y
%ifarch x86_64
sh -c "source $HOME/.cargo/env; rustup target add x86_64-unknown-linux-musl"
if ! sh -c "source $HOME/.cargo/env; cargo build --release --target x86_64-unknown-linux-musl" ; then
	rm -rf $(find|grep cfg-if)
	sh -c "source $HOME/.cargo/env; cargo build --release --target x86_64-unknown-linux-musl" 
fi 
%endif
%ifarch aarch64
[[ -f ~/bin/aarch64-linux-musl-gcc ]] || ln -s /usr/bin/aarch64-redhat-linux-gcc ~/bin/aarch64-linux-musl-gcc
sh -c "source $HOME/.cargo/env; rustup target add aarch64-unknown-linux-musl"
if ! sh -c "source $HOME/.cargo/env; cargo build --release --target aarch64-unknown-linux-musl" ; then
	rm -rf $(find|grep cfg-if)
	sh -c "source $HOME/.cargo/env; cargo build --release --target aarch64-unknown-linux-musl" 
fi 
[[ -f ~/bin/aarch64-linux-musl-gcc ]] && rm ~/bin/aarch64-linux-musl-gcc
%endif

%install
%ifarch x86_64
%{__install} -Dp -m755 target/x86_64-unknown-linux-musl/release/avml         %{buildroot}%{_bindir}/avml
%{__install} -Dp -m755 target/x86_64-unknown-linux-musl/release/avml-convert %{buildroot}%{_bindir}/avml-convert
%endif
%ifarch aarch64
%{__install} -Dp -m755 target/aarch64-unknown-linux-musl/release/avml         %{buildroot}%{_bindir}/avml
%{__install} -Dp -m755 target/aarch64-unknown-linux-musl/release/avml-convert %{buildroot}%{_bindir}/avml-convert
%endif

%clean
%{__rm} -rf %{buildroot} $HOME/.cargo

%files
%defattr(-, root, root, 0755)
%doc 
%attr(755, root, root)	%{_bindir}/%{name}
%attr(755, root, root)	%{_bindir}/%{name}-convert

%changelog
%if 0%{?centos} == 8 || 0%{?centos} == 7
%else
* Fri May 26 2023 Lawrence R. Rogers <lrr@cert.org> 0.11.3-1
* Release 0.11.3-1
	Version 0.11.3

* Wed Apr 19 2023 Lawrence R. Rogers <lrr@cert.org> 0.11.2-1
* Release 0.11.2-1
	Version 0.11.2

* Wed Feb  1 2023 Lawrence R. Rogers <lrr@cert.org> 0.11.0-1
* Release 0.11.0-1
	Version 0.11.0

%endif
* Thu Jun 24 2021 Lawrence R. Rogers <lrr@cert.org> 0.3.0-1
* Release 0.3.0-1
	Version 0.3.0

* Tue Dec  1 2020 Lawrence R. Rogers <lrr@cert.org> 0.2.1-1
* Release 0.2.1-1
	Version 0.2.1
	Initial release

